==> forms-v5.2.1.tar.gz: forms/l10n/sc.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Mòdulos",
    "{user} has shared the form {formTitle} with you" : "{user} at cumpartzidu su mòdulu {formTitle} cun tegus",
    "{user} has shared the form {formTitle} with group {group}" : "{user} at cumpartzidu su mòdulu {formTitle} cun su grupu {group}",
    "Anonymous user" : "Utente chene nùmene",
    "A form has been <strong>shared</strong> with you" : "Ant cumpartzidu unu <strong>mòdulu</strong> cun tegus",
    "Someone <strong>answered</strong> a form" : "Ant <strong>rispostu </strong> a unu mòdulu",
    "No" : "No",
    "Yes" : "Si",
    "Copy" : "Còpia",
    "Anonymous response" : "Risposta anònima",
    "Shared by %s" : "Cumpartzidu dae %s",
    "responses" : "rispostas",
    "User display name" : "Nùmene ammustradu a s'utente",
    "Timestamp" : "Marca temporale",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Sondàgios e cuestionàrios simpres, autònomos",
    "An error occurred while loading the forms list" : "B'at àpidu un'errore in su carrigamentu de sa lista de mòdulos",
    "Form not found" : "Mòdulu no agatadu",
    "Unable to create a new form" : "Non faghet a creare unu mòdulu nou",
    "Unable to copy form" : "No at fatu a copiare su mòdulu",
    "New form" : "Mòdulu nou",
    "Shared with you" : "Cumpartzidos cun tegus",
    "Loading forms …" : "Carrighende mòdulos …",
    "No forms created yet" : "Ancora perunu mòdulu creadu",
    "Create a form" : "Crea unu mòdulu",
    "Select a form or create a new one" : "Seletziona unu mòdulu o crea·nde unu nou",
    "Create new form" : "Crea unu mòdulu nou",
    "This form does not exist" : "Custu mòdulu no esistit",
    "Form expired" : "Su mòdulu est iscadidu",
    "This form has expired and is no longer taking answers" : "Custu mòdulu est iscadidu e no atzetat prus rispostas",
    "Select groups" : "Seletziona grupos",
    "Delete form" : "Cantzella mòdulu",
    "Error while deleting {title}" : "Errore in sa cantzelladura de {title}",
    "Share form" : "Cumpartzi mòdulu",
    "Results" : "Resurtados",
    "Copy form" : "Còpia mòdulu",
    "Are you sure you want to delete {title}?" : "A beru boles cantzellare {title}?",
    "Cancel" : "Annulla",
    "Options should be separated by new line!" : "Is optziones depent èssere partzidas cun lìnias noas.",
    "Options" : "Optziones",
    "Answer number {index}" : "Risposta nùmeru {index}",
    "Error while saving the answer" : "Errore sarvende sa risposta",
    "Delete answer" : "Cantzella risposta",
    "This question needs a title!" : "Sa pregonta bolet unu tìtulu!",
    "Question number {index}" : "Pregonta nùmeru {index}",
    "Title of question number {index}" : "Tìtulu de sa pregonta nùmeru {index}",
    "Required" : "Rechertu",
    "Delete question" : "Cantzella pregonta",
    "Maximum file size" : "Mannària màssima de s'archìviu",
    "Delete" : "Cantzella",
    "Uploading …" : "Carrighende ...",
    "Add new file as answer" : "Agiunghe archìviu nou comente risposta",
    "A long answer for the question “{text}”" : "Una risposta longa pro sa pregonta “{text}”",
    "Other" : "Àteru",
    "A short answer for the question “{text}”" : "Una risposta curtza pro sa pregonta “{text}”",
    "No response" : "Peruna risposta",
    "Delete this response" : "Cantzella custa risposta",
    "Expired on {date}" : "Iscadidu su {date}",
    "Expires on {date}" : "Iscadit su {date}",
    "never" : "mai",
    "Allow multiple responses per person" : "Permite rispostas mùltiplas pro persone",
    "Set expiration date" : "Cunfigura una data de iscadèntzia",
    "Closed forms do not accept new submissions." : "Is formulàrios serrados no atzetant imbios noos.",
    "Archived forms do not accept new submissions and can not be modified." : "Is formulàrios archiviados no atzetant imbios noos e non podent èssere modificados.",
    "Group" : "Grupu",
    "Permissions" : "Permissos",
    "Share link" : "Cumpartzi ligòngiu",
    "Add link" : "Agiunghe ligòngiu",
    "Copy to clipboard" : "Còpia in is punta de billete",
    "Copy embedding code" : "Còpia su còdighe de insertada",
    "Internal link" : "Ligòngiu de intro",
    "Only works for logged in accounts with access rights" : "Funtzionat isceti pro contos identificados cun deretu de atzessu",
    "View" : "Visualiza",
    "Edit" : "Modìfica",
    "Share" : "Cumpartzidura",
    "Responses are anonymous." : "Is rispostas sunt anònimas.",
    "An asterisk (*) indicates mandatory questions." : "Un'asteriscu (*) inditat is pregontas obligatòrias.",
    "There was an error while adding the new question" : "Ddoe at àpidu un'errore agiunghende sa pregonta noa",
    "There was an error while removing the question" : "Ddoe at àpidu un'errore boghende·nche sa pregonta",
    "Error while saving form" : "Errore sarvende su mòdulu",
    "Loading {title} …" : "Carrighende {title} …",
    "Form title" : "Tìtulu de su mòdulu",
    "Description" : "Descritzione",
    "Add a question" : "Agiunghe una pregonta",
    "Summary" : "Resumu",
    "Responses" : "Rispostas",
    "There was an error while loading the results" : "Errore in su carrigamentu de is resurtados",
    "Export successful to {file}" : "Esportatzione fata a {file}",
    "There was an error, while exporting to Files" : "Ddoe at àpidu un'errore in s'esportatzione a Archìvios",
    "There was an error while removing this response" : "Ddoe at àpidu un'errore boghende·nche custa risposta",
    "There was an error while removing responses" : "Ddoe at àpidu un'errore boghende·nche is rispostas",
    "Linked file is not available, would you like to link a new file?" : "S'archìviu alligongiadu no est a disponimentu, boles creare unu ligòngiu a un'archìviu nou?",
    "{amount} responses" : "{amount} rispostas",
    "Download" : "Iscàrriga",
    "Delete all responses" : "Cantzella totu is rispostas",
    "Search" : "Chirca",
    "Loading responses …" : "Carrighende is rispostas ...",
    "No results found" : "Perunu resurtadu agatadu",
    "No responses yet" : "Ancora peruna risposta",
    "Results of submitted forms will show up here" : "Is resurtados de is mòdulos imbiados s'ant a mustrare inoghe",
    "Are you sure you want to delete all responses of {title}?" : "A beru boles cantzellare totu is rispostas de {title}?",
    "Sharing" : "Cumpartzidura",
    "Settings" : "Cunfiguratzione",
    "Abort" : "Annulla",
    "Submit" : "Imbia",
    "Clear" : "Lìmpia",
    "There was an error submitting the form" : "B'at àpidu un'errore imbiende su mòdulu",
    "Submit form" : "Imbia mòdulu",
    "Submitting form …" : "Imbia mòdulu …",
    "Thank you for completing the form!" : "Gràtzias pro àere cumpletadu su mòdulu!",
    "You have unsaved changes! Do you still want to leave?" : "No as sarvadu is modìficas! A beru boles essire?",
    "Error while saving question" : "Errore sarvende sa pregonta",
    "There was an issue deleting this option" : "Ddoe at àpidu unu problema cantzellende custa optzione",
    "Form link copied" : "Ligòngiu de su mòdulu copiadu",
    "Cannot copy, please copy the link manually" : "No at fatu a copiare, copia su ligòngiu a manu",
    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
    "No elements found." : "Perunu elementu agatadu.",
    "Checkboxes" : "Casellas de seletzione",
    "Checkbox question title" : "Tìtulu de sa pregonta cun casella de seletzione",
    "This question needs a title and at least one answer!" : "A custa pregonta ddi serbit unu tìtulu e a su mancu una risposta!",
    "Dropdown" : "Calada",
    "Dropdown question title" : "Tìtulu de sa pregonta a calada",
    "People can pick one option" : "Sa gente podet seberare un'optzione",
    "Pick an option" : "Sèbera un'optzione",
    "File" : "Archìviu",
    "Short answer" : "Risposta curtza",
    "Short answer question title" : "Tìtulu de sa pregonta a risposta curtza",
    "People can enter a short answer" : "Sa gente podet insertare una risposta curtza",
    "Long text" : "Testu longu",
    "Long text question title" : "Tìtulu de sa pregonta a testu longu",
    "People can enter a long text" : "Sa gente podet insertare unu testu longu",
    "Date" : "Data",
    "Date question title" : "Tìtulu de sa pregonta cun data",
    "People can pick a date" : "Sa gente podet seberare una data",
    "Pick a date" : "Sèbera una data",
    "Datetime" : "Data e ora",
    "Datetime question title" : "Tìtulu de sa pregonta cun data e ora",
    "People can pick a date and time" : "Sa gente podet seberare data e ora",
    "Pick a date and time" : "Sèbera data e ora",
    "Time" : "Ora",
    "Pick a time" : "Sèbera una ora",
    "Color" : "Colore",
    "Image" : "Immàgine",
    "Document" : "Documentu",
    "Presentation" : "Presentatzione",
    "Text" : "Testu",
    "Phone number" : "Nùmeru de telèfonu",
    "Email address" : "Indiritzu de posta eletrònica"
},
"nplurals=2; plural=(n != 1);");

==> forms-v5.2.2.tar.gz: forms/l10n/sc.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Mòdulos",
    "{user} has shared the form {formTitle} with you" : "{user} at cumpartzidu su mòdulu {formTitle} cun tegus",
    "{user} has shared the form {formTitle} with group {group}" : "{user} at cumpartzidu su mòdulu {formTitle} cun su grupu {group}",
    "Anonymous user" : "Utente chene nùmene",
    "A form has been <strong>shared</strong> with you" : "Ant cumpartzidu unu <strong>mòdulu</strong> cun tegus",
    "Someone <strong>answered</strong> a form" : "Ant <strong>rispostu </strong> a unu mòdulu",
    "No" : "No",
    "Yes" : "Si",
    "Copy" : "Còpia",
    "Anonymous response" : "Risposta anònima",
    "Shared by %s" : "Cumpartzidu dae %s",
    "responses" : "rispostas",
    "User display name" : "Nùmene ammustradu a s'utente",
    "Timestamp" : "Marca temporale",
    "📝 Simple surveys and questionnaires, self-hosted" : "📝 Sondàgios e cuestionàrios simpres, autònomos",
    "An error occurred while loading the forms list" : "B'at àpidu un'errore in su carrigamentu de sa lista de mòdulos",
    "Form not found" : "Mòdulu no agatadu",
    "Unable to create a new form" : "Non faghet a creare unu mòdulu nou",
    "Unable to copy form" : "No at fatu a copiare su mòdulu",
    "New form" : "Mòdulu nou",
    "Shared with you" : "Cumpartzidos cun tegus",
    "No forms created yet" : "Ancora perunu mòdulu creadu",
    "Create a form" : "Crea unu mòdulu",
    "Select a form or create a new one" : "Seletziona unu mòdulu o crea·nde unu nou",
    "Create new form" : "Crea unu mòdulu nou",
    "This form does not exist" : "Custu mòdulu no esistit",
    "Form expired" : "Su mòdulu est iscadidu",
    "This form has expired and is no longer taking answers" : "Custu mòdulu est iscadidu e no atzetat prus rispostas",
    "Select groups" : "Seletziona grupos",
    "Delete form" : "Cantzella mòdulu",
    "Error while deleting {title}" : "Errore in sa cantzelladura de {title}",
    "Share form" : "Cumpartzi mòdulu",
    "Results" : "Resurtados",
    "Copy form" : "Còpia mòdulu",
    "Are you sure you want to delete {title}?" : "A beru boles cantzellare {title}?",
    "Cancel" : "Annulla",
    "Options should be separated by new line!" : "Is optziones depent èssere partzidas cun lìnias noas.",
    "Options" : "Optziones",
    "Answer number {index}" : "Risposta nùmeru {index}",
    "Error while saving the answer" : "Errore sarvende sa risposta",
    "Delete answer" : "Cantzella risposta",
    "This question needs a title!" : "Sa pregonta bolet unu tìtulu!",
    "Question number {index}" : "Pregonta nùmeru {index}",
    "Title of question number {index}" : "Tìtulu de sa pregonta nùmeru {index}",
    "Required" : "Rechertu",
    "Delete question" : "Cantzella pregonta",
    "Maximum file size" : "Mannària màssima de s'archìviu",
    "Delete" : "Cantzella",
    "Add new file as answer" : "Agiunghe archìviu nou comente risposta",
    "A long answer for the question “{text}”" : "Una risposta longa pro sa pregonta “{text}”",
    "Other" : "Àteru",
    "A short answer for the question “{text}”" : "Una risposta curtza pro sa pregonta “{text}”",
    "No response" : "Peruna risposta",
    "Delete this response" : "Cantzella custa risposta",
    "Expired on {date}" : "Iscadidu su {date}",
    "Expires on {date}" : "Iscadit su {date}",
    "never" : "mai",
    "Allow multiple responses per person" : "Permite rispostas mùltiplas pro persone",
    "Set expiration date" : "Cunfigura una data de iscadèntzia",
    "Closed forms do not accept new submissions." : "Is formulàrios serrados no atzetant imbios noos.",
    "Archived forms do not accept new submissions and can not be modified." : "Is formulàrios archiviados no atzetant imbios noos e non podent èssere modificados.",
    "Group" : "Grupu",
    "Permissions" : "Permissos",
    "Share link" : "Cumpartzi ligòngiu",
    "Add link" : "Agiunghe ligòngiu",
    "Copy to clipboard" : "Còpia in is punta de billete",
    "Copy embedding code" : "Còpia su còdighe de insertada",
    "Internal link" : "Ligòngiu de intro",
    "Only works for logged in accounts with access rights" : "Funtzionat isceti pro contos identificados cun deretu de atzessu",
    "View" : "Visualiza",
    "Edit" : "Modìfica",
    "Share" : "Cumpartzidura",
    "Responses are anonymous." : "Is rispostas sunt anònimas.",
    "An asterisk (*) indicates mandatory questions." : "Un'asteriscu (*) inditat is pregontas obligatòrias.",
    "There was an error while adding the new question" : "Ddoe at àpidu un'errore agiunghende sa pregonta noa",
    "There was an error while removing the question" : "Ddoe at àpidu un'errore boghende·nche sa pregonta",
    "Error while saving form" : "Errore sarvende su mòdulu",
    "Form title" : "Tìtulu de su mòdulu",
    "Description" : "Descritzione",
    "Add a question" : "Agiunghe una pregonta",
    "Summary" : "Resumu",
    "Responses" : "Rispostas",
    "There was an error while loading the results" : "Errore in su carrigamentu de is resurtados",
    "Export successful to {file}" : "Esportatzione fata a {file}",
    "There was an error, while exporting to Files" : "Ddoe at àpidu un'errore in s'esportatzione a Archìvios",
    "There was an error while removing this response" : "Ddoe at àpidu un'errore boghende·nche custa risposta",
    "There was an error while removing responses" : "Ddoe at àpidu un'errore boghende·nche is rispostas",
    "Linked file is not available, would you like to link a new file?" : "S'archìviu alligongiadu no est a disponimentu, boles creare unu ligòngiu a un'archìviu nou?",
    "{amount} responses" : "{amount} rispostas",
    "Download" : "Iscàrriga",
    "Delete all responses" : "Cantzella totu is rispostas",
    "Search" : "Chirca",
    "No results found" : "Perunu resurtadu agatadu",
    "No responses yet" : "Ancora peruna risposta",
    "Results of submitted forms will show up here" : "Is resurtados de is mòdulos imbiados s'ant a mustrare inoghe",
    "Are you sure you want to delete all responses of {title}?" : "A beru boles cantzellare totu is rispostas de {title}?",
    "Sharing" : "Cumpartzidura",
    "Settings" : "Cunfiguratzione",
    "Abort" : "Annulla",
    "Submit" : "Imbia",
    "Clear" : "Lìmpia",
    "There was an error submitting the form" : "B'at àpidu un'errore imbiende su mòdulu",
    "Submit form" : "Imbia mòdulu",
    "Thank you for completing the form!" : "Gràtzias pro àere cumpletadu su mòdulu!",
    "You have unsaved changes! Do you still want to leave?" : "No as sarvadu is modìficas! A beru boles essire?",
    "Error while saving question" : "Errore sarvende sa pregonta",
    "There was an issue deleting this option" : "Ddoe at àpidu unu problema cantzellende custa optzione",
    "Form link copied" : "Ligòngiu de su mòdulu copiadu",
    "Cannot copy, please copy the link manually" : "No at fatu a copiare, copia su ligòngiu a manu",
    "No recommendations. Start typing." : "Peruna racumandatzione. Cumintza a iscrìere.",
    "No elements found." : "Perunu elementu agatadu.",
    "Checkboxes" : "Casellas de seletzione",
    "Checkbox question title" : "Tìtulu de sa pregonta cun casella de seletzione",
    "This question needs a title and at least one answer!" : "A custa pregonta ddi serbit unu tìtulu e a su mancu una risposta!",
    "Dropdown" : "Calada",
    "Dropdown question title" : "Tìtulu de sa pregonta a calada",
    "People can pick one option" : "Sa gente podet seberare un'optzione",
    "Pick an option" : "Sèbera un'optzione",
    "File" : "Archìviu",
    "Short answer" : "Risposta curtza",
    "Short answer question title" : "Tìtulu de sa pregonta a risposta curtza",
    "People can enter a short answer" : "Sa gente podet insertare una risposta curtza",
    "Long text" : "Testu longu",
    "Long text question title" : "Tìtulu de sa pregonta a testu longu",
    "People can enter a long text" : "Sa gente podet insertare unu testu longu",
    "Date" : "Data",
    "Date question title" : "Tìtulu de sa pregonta cun data",
    "People can pick a date" : "Sa gente podet seberare una data",
    "Pick a date" : "Sèbera una data",
    "Datetime" : "Data e ora",
    "Datetime question title" : "Tìtulu de sa pregonta cun data e ora",
    "People can pick a date and time" : "Sa gente podet seberare data e ora",
    "Pick a date and time" : "Sèbera data e ora",
    "Time" : "Ora",
    "Pick a time" : "Sèbera una ora",
    "Color" : "Colore",
    "Image" : "Immàgine",
    "Document" : "Documentu",
    "Presentation" : "Presentatzione",
    "Text" : "Testu",
    "Phone number" : "Nùmeru de telèfonu",
    "Email address" : "Indiritzu de posta eletrònica",
    "Loading forms …" : "Carrighende mòdulos …",
    "Uploading …" : "Carrighende ...",
    "Loading {title} …" : "Carrighende {title} …",
    "Loading responses …" : "Carrighende is rispostas ...",
    "Submitting form …" : "Imbia mòdulu …"
},
"nplurals=2; plural=(n != 1);");
